@@ -95,10 +95,12 @@ class WaifuAioClient:
         return infos.get('url')
 
 
-    async def _fetchgallery(self, insert, delete,token=None):
+    async def _fetchgallery(self, id, insert, delete, token):
         """process the request for a specific tag and check if everything is correct."""
         params={}
         headers={}
+        if id:
+            params.update({'id':id})
         if delete:
             params.update({'delete':','.join(delete)})
         if insert:
@@ -156,7 +158,7 @@ class WaifuAioClient:
         return data
 
     @requires_token
-    async def fav(self, insert: List[str]=None, delete: List[str]=None, token: str=None):
+    async def fav(self, id: str=None,insert: List[str]=None, delete: List[str]=None, token: str=None):
         """Get your favorite gallery.""
 
         Kwargs:
@@ -168,7 +170,7 @@ class WaifuAioClient:
         Raises:
             APIException: If the API response contains an error.
         """
-        return await self._fetchgallery(insert,delete,token=token)
+        return await self._fetchgallery(id,insert,delete,token)
 
     async def endpoints(self, full=False):
         """Gets the API endpoints.
